@@ -3,9 +3,7 @@ def foo(&b)
   1.times(&b)
 end
 
-# TODO: Object means "void"
-
 ## assert
 class Object
-  def foo: { (Integer) -> Object } -> Integer
+  def foo: { (Integer) -> untyped } -> Integer
 end
