@@ -6,7 +6,6 @@ def foo(n)
   n = "str"
   1.0
 ensure
-  ## TODO: bar should accept "Integer | String" ???
   bar(n)
 end
 
@@ -14,6 +13,6 @@ foo(1)
 
 ## assert
 class Object
-  def bar: (String) -> nil
-  def foo: (Integer) -> Float?
+  def bar: (Integer | String) -> nil
+  def foo: (Integer) -> Float
 end
